package org.apache.bcel.classfile;

import java.io.DataInput;
import java.io.DataOutputStream;
import java.io.IOException;

/* loaded from: org_apache_bcel_classfile.jar:org/apache/bcel/classfile/Synthetic.class */
public final class Synthetic extends Attribute {
    private byte[] bytes;

    public Synthetic(int nameIndex, int length, byte[] bytes, ConstantPool constantPool) {
        super((byte) 7, nameIndex, length, constantPool);
        this.bytes = bytes;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public Synthetic(int nameIndex, int length, DataInput input, ConstantPool constantPool) throws IOException {
        this(nameIndex, length, (byte[]) null, constantPool);
        if (length > 0) {
            this.bytes = new byte[length];
            input.readFully(this.bytes);
            println("Synthetic attribute with length > 0");
        }
    }

    public Synthetic(Synthetic c) {
        this(c.getNameIndex(), c.getLength(), c.getBytes(), c.getConstantPool());
    }

    @Override // org.apache.bcel.classfile.Attribute, org.apache.bcel.classfile.Node
    public void accept(Visitor v) {
        v.visitSynthetic(this);
    }

    @Override // org.apache.bcel.classfile.Attribute
    public Attribute copy(ConstantPool constantPool) {
        Synthetic c = (Synthetic) clone();
        if (this.bytes != null) {
            c.bytes = (byte[]) this.bytes.clone();
        }
        c.setConstantPool(constantPool);
        return c;
    }

    @Override // org.apache.bcel.classfile.Attribute
    public void dump(DataOutputStream file) throws IOException {
        super.dump(file);
        if (super.getLength() > 0) {
            file.write(this.bytes, 0, super.getLength());
        }
    }

    public byte[] getBytes() {
        return this.bytes;
    }

    public void setBytes(byte[] bytes) {
        this.bytes = bytes;
    }

    @Override // org.apache.bcel.classfile.Attribute
    public String toString() {
        StringBuilder buf = new StringBuilder("Synthetic");
        if (super.getLength() > 0) {
            buf.append(" ").append(Utility.toHexString(this.bytes));
        }
        return buf.toString();
    }
}
